==> codedeploy-0.9.2-sources.jar: software/amazon/awscdk/services/codedeploy/cloudformation/DeploymentConfigResource.java <==
package software.amazon.awscdk.services.codedeploy.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codedeploy-deploymentconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-20T13:05:15.959Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codedeploy.$Module.class, fqn = "@aws-cdk/aws-codedeploy.cloudformation.DeploymentConfigResource")
public class DeploymentConfigResource extends software.amazon.awscdk.Resource {
    protected DeploymentConfigResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::CodeDeploy::DeploymentConfig``.
     * @param parent the ``cdk.Construct`` this ``DeploymentConfigResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``DeploymentConfigResource``
     */
    public DeploymentConfigResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::CodeDeploy::DeploymentConfig``.
     * @param parent the ``cdk.Construct`` this ``DeploymentConfigResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public DeploymentConfigResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getDeploymentConfigId() {
        return this.jsiiGet("deploymentConfigId", java.lang.String.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html
     */
    public static interface MinimumHealthyHostsProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        java.lang.Object getType();
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        void setType(final java.lang.String value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        void setType(final software.amazon.awscdk.CloudFormationToken value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        java.lang.Object getValue();
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        void setValue(final java.lang.Number value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        void setValue(final software.amazon.awscdk.CloudFormationToken value);

        /**
         * @return a {@link Builder} of {@link MinimumHealthyHostsProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link MinimumHealthyHostsProperty}
         */
        final class Builder {
            private java.lang.Object _type;
            private java.lang.Object _value;

            /**
             * Sets the value of Type
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @return {@code this}
             */
            public Builder withType(final java.lang.String value) {
                this._type = java.util.Objects.requireNonNull(value, "type is required");
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @return {@code this}
             */
            public Builder withType(final software.amazon.awscdk.CloudFormationToken value) {
                this._type = java.util.Objects.requireNonNull(value, "type is required");
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(final java.lang.Number value) {
                this._value = java.util.Objects.requireNonNull(value, "value is required");
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(final software.amazon.awscdk.CloudFormationToken value) {
                this._value = java.util.Objects.requireNonNull(value, "value is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link MinimumHealthyHostsProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public MinimumHealthyHostsProperty build() {
                return new MinimumHealthyHostsProperty() {
                    private java.lang.Object $type = java.util.Objects.requireNonNull(_type, "type is required");
                    private java.lang.Object $value = java.util.Objects.requireNonNull(_value, "value is required");

                    @Override
                    public java.lang.Object getType() {
                        return this.$type;
                    }

                    @Override
                    public void setType(final java.lang.String value) {
                        this.$type = java.util.Objects.requireNonNull(value, "type is required");
                    }

                    @Override
                    public void setType(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$type = java.util.Objects.requireNonNull(value, "type is required");
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(final java.lang.Number value) {
                        this.$value = java.util.Objects.requireNonNull(value, "value is required");
                    }

                    @Override
                    public void setValue(final software.amazon.awscdk.CloudFormationToken value) {
                        this.$value = java.util.Objects.requireNonNull(value, "value is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResource.MinimumHealthyHostsProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public java.lang.Object getType() {
                return this.jsiiGet("type", java.lang.Object.class);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public void setType(final java.lang.String value) {
                this.jsiiSet("type", java.util.Objects.requireNonNull(value, "type is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public void setType(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("type", java.util.Objects.requireNonNull(value, "type is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public void setValue(final java.lang.Number value) {
                this.jsiiSet("value", java.util.Objects.requireNonNull(value, "value is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public void setValue(final software.amazon.awscdk.CloudFormationToken value) {
                this.jsiiSet("value", java.util.Objects.requireNonNull(value, "value is required"));
            }
        }
    }
}

==> codedeploy-0.11.0-sources.jar: software/amazon/awscdk/services/codedeploy/cloudformation/DeploymentConfigResource.java <==
package software.amazon.awscdk.services.codedeploy.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codedeploy-deploymentconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T18:05:39.206Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codedeploy.$Module.class, fqn = "@aws-cdk/aws-codedeploy.cloudformation.DeploymentConfigResource")
public class DeploymentConfigResource extends software.amazon.awscdk.Resource {
    protected DeploymentConfigResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::CodeDeploy::DeploymentConfig``.
     * @param parent the ``cdk.Construct`` this ``DeploymentConfigResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``DeploymentConfigResource``
     */
    public DeploymentConfigResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, @javax.annotation.Nullable final software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(properties)).toArray());
    }
    /**
     * Creates a new ``AWS::CodeDeploy::DeploymentConfig``.
     * @param parent the ``cdk.Construct`` this ``DeploymentConfigResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     */
    public DeploymentConfigResource(final software.amazon.awscdk.Construct parent, final java.lang.String name) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getDeploymentConfigId() {
        return this.jsiiGet("deploymentConfigId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html
     */
    public static interface MinimumHealthyHostsProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        java.lang.Object getType();
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        void setType(final java.lang.String value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
         */
        void setType(final software.amazon.awscdk.Token value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        java.lang.Object getValue();
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        void setValue(final java.lang.Number value);
        /**
         * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
         */
        void setValue(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link MinimumHealthyHostsProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link MinimumHealthyHostsProperty}
         */
        final class Builder {
            private java.lang.Object _type;
            private java.lang.Object _value;

            /**
             * Sets the value of Type
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @return {@code this}
             */
            public Builder withType(final java.lang.String value) {
                this._type = java.util.Objects.requireNonNull(value, "type is required");
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @return {@code this}
             */
            public Builder withType(final software.amazon.awscdk.Token value) {
                this._type = java.util.Objects.requireNonNull(value, "type is required");
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(final java.lang.Number value) {
                this._value = java.util.Objects.requireNonNull(value, "value is required");
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(final software.amazon.awscdk.Token value) {
                this._value = java.util.Objects.requireNonNull(value, "value is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link MinimumHealthyHostsProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public MinimumHealthyHostsProperty build() {
                return new MinimumHealthyHostsProperty() {
                    private java.lang.Object $type = java.util.Objects.requireNonNull(_type, "type is required");
                    private java.lang.Object $value = java.util.Objects.requireNonNull(_value, "value is required");

                    @Override
                    public java.lang.Object getType() {
                        return this.$type;
                    }

                    @Override
                    public void setType(final java.lang.String value) {
                        this.$type = java.util.Objects.requireNonNull(value, "type is required");
                    }

                    @Override
                    public void setType(final software.amazon.awscdk.Token value) {
                        this.$type = java.util.Objects.requireNonNull(value, "type is required");
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(final java.lang.Number value) {
                        this.$value = java.util.Objects.requireNonNull(value, "value is required");
                    }

                    @Override
                    public void setValue(final software.amazon.awscdk.Token value) {
                        this.$value = java.util.Objects.requireNonNull(value, "value is required");
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.cloudformation.DeploymentConfigResource.MinimumHealthyHostsProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public java.lang.Object getType() {
                return this.jsiiGet("type", java.lang.Object.class);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public void setType(final java.lang.String value) {
                this.jsiiSet("type", java.util.Objects.requireNonNull(value, "type is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-type
             */
            @Override
            public void setType(final software.amazon.awscdk.Token value) {
                this.jsiiSet("type", java.util.Objects.requireNonNull(value, "type is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public void setValue(final java.lang.Number value) {
                this.jsiiSet("value", java.util.Objects.requireNonNull(value, "value is required"));
            }

            /**
             * ``DeploymentConfigResource.MinimumHealthyHostsProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentconfig-minimumhealthyhosts.html#cfn-codedeploy-deploymentconfig-minimumhealthyhosts-value
             */
            @Override
            public void setValue(final software.amazon.awscdk.Token value) {
                this.jsiiSet("value", java.util.Objects.requireNonNull(value, "value is required"));
            }
        }
    }
}
